#!/usr/bin/env python

import sys
import fileinput
import datetime as dt
import math

deltas = []

def mean(values):
    return float(sum(values)) / len(values)

def stddev(values):
    n = len(values)
    sq_values = [value * value for value in values]
    mu_sq_values = mean(sq_values)
    mu_values = mean(values)
    return math.sqrt(mu_sq_values / (n-1) - n/(n-1) * (mu_values / n)**2)

# XXX assumes values are pre-sorted
def median(values):
    n = len(values)
    if (n % 2) == 0:
        median_value = (values[n / 2 - 1] + values[n/2]) / 2
    else:
        median_value = values[n / 2]
    return median_value

def parse_time(tstr):
    tzone_delim = tstr.rfind('-') # don't care about utc offset
    parsed_time = dt.datetime.strptime(tstr[:tzone_delim], "%Y-%m-%dT%H:%M:%S.%f");
    return parsed_time

doing_test = False
start_time = finish_time = None
num_trials = 0
for line in fileinput.input():
    tok = line.split()
    if tok[-1] == "finish":
        if num_trials < 2:
            # Skip the first and second times to avoid skew
            num_trials += 1
            doing_test = False
            continue
        if doing_test == False:
            raise ValueError("Finishing a test twice")
        num_trials += 1
        doing_test = False
        finish_time = parse_time(tok[0])
        deltas.append(finish_time - start_time);
    elif tok[-1] == "start":
        if doing_test == True:
            raise ValueError("Starting a test twice")
        doing_test = True
        start_time = parse_time(tok[0])
    else:
        raise ValueError("Unknown type!");

ideltas = [float(delta.microseconds + (delta.seconds + delta.days * 24 * 3600) * 10 ** 6) / 10 ** 6 for delta in deltas]
ideltas.sort();

print "BEGIN DATA"

for i, delta in enumerate(deltas):
    sys.stdout.write("Trial %d: " % i)
    print delta

print "END DATA"

print "SUMMARY: Time in seconds"
print "Mean = %f" % (mean(ideltas));
print "Standard deviation = %f" % (stddev(ideltas));
print "Median = %f" % (median(ideltas));

sys.exit(0)
