#!/usr/bin/env python

import sys
import matplotlib.pyplot as plt

kernels = ["2.6.32-131.0.15.el6.x86_64", "2.6.32-220.17.1.el6.x86_64"]
colors = ["#ff3333", "#3333ff"]
features = ["max", "min", "mean", "median"]

def mean(values):
    return float(sum(values)) / len(values)

def median(values):
    sorted_values = values
    sorted_values.sort()
    n = len(sorted_values)
    if (n % 2) == 0:
        median_value = (sorted_values[n / 2 - 1] + sorted_values[n/2]) / 2
    else:
        median_value = sorted_values[n / 2]
    return median_value

# Build data
iterations = {}
trials = {}
feature_values = {}
for kernel in kernels:
    # load the csv data: [ [data for iteration 1], [data for iteration 2], ... ]
    csvdata = [l.strip().split(',') for l in open("../logs/" + kernel + ".csv").readlines()]
    iterations[kernel] = []
    for csvdatum in csvdata:
        iterations[kernel].append(map(lambda (x) : float(x), csvdatum))
    feature_values[kernel] = {}
    feature_values[kernel]["max"] = []
    feature_values[kernel]["min"] = []
    feature_values[kernel]["mean"] = []
    feature_values[kernel]["median"] = []
    trials[kernel] = [[] for i in range(0,len(iterations[kernel][0]))]
    for iteration in iterations[kernel]:
        feature_values[kernel]["max"].append(max(iteration))
        feature_values[kernel]["min"].append(min(iteration))
        feature_values[kernel]["mean"].append(mean(iteration))
        feature_values[kernel]["median"].append(median(iteration))
        for i, trial in enumerate(iteration):
            trials[kernel][i].append(trial)


# Graph the data
for feature in features:
    iteration_range = range(0,len(iterations[kernel]))
    for k, kernel in enumerate(kernels):
        for trial in trials[kernel]:
            plt.plot(iteration_range, trial, '.', color=colors[k])
        plt.plot(iteration_range, feature_values[kernel][feature], '-', label=feature + " "  + kernel,
                color=colors[k])
    plt.legend()
    axes = plt.gca()
    legend = axes.get_legend()
    ltext = legend.get_texts()
    lframe = legend.get_frame()
    lframe.set_alpha(0.5)
    axes.set_xlabel("Iteration")
    axes.set_ylabel("Time (s)")
    plt.setp(ltext, fontsize='small')
    plt.savefig("regression-" + feature + ".png", bbox_inches="tight", dpi=300)
    plt.clf()
